@@ -7,8 +7,8 @@ from time import sleep
 
 class LightSensor:
 
-    def __init__(self, measure_period: int):
-        self.measure_period = measure_period
+    def __init__(self):
+        self.measures = list()
         i2c = board.I2C()
         self.sensor = adafruit_bh1750.BH1750(i2c)
         logging.info("light sensor connected")
@@ -17,10 +17,18 @@ class LightSensor:
         Thread(target=self.__listen, args=(listener,), daemon=True).start()
 
     def __listen(self, listener):
+        loop = 0
         while True:
             try:
-                listener(int(self.sensor.lux))
+                self.measures.append(self.sensor.lux)
+                while len(self.measures) > 5:
+                    self.measures.pop(0)
+                loop +=1
+                if loop > 5:
+                    loop = 0
+                    median = self.measures[int(len(self.measures) * 0.5)]
+                    listener(int(median))
             except Exception as e:
                 print("error occurred", e)
-            sleep(self.measure_period)
+            sleep(1)
 
